<?php
/**
 * Frontech functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Frontech
 */

include(get_stylesheet_directory() . '/default_options_child.php');

function frontech_enqueue_styles() {
	$frontech_theme_options = frontech_theme_options();
	$kyma_theme_options = kyma_theme_options();
    $parent_style = 'parent-style'; // This is 'twentyfifteen-style' for the Twenty Fifteen theme.

    wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css', array( 'bootstrap' )  );
    wp_enqueue_style( 'frontech',
        get_stylesheet_directory_uri() . '/style.css',
        array( $parent_style, 'bootstrap' ),
        wp_get_theme()->get('Version')
    );
	
	wp_dequeue_style('responsive');
	wp_enqueue_style('frontech-responsive', get_stylesheet_directory_uri() . '/css/responsive.css');
	
	if(!isset( $kyma_theme_options['color_scheme_child'] )){
		$kyma_theme_options['color_scheme_child'] = $frontech_theme_options['color_scheme_child'];
	}
	//print_r($kyma_theme_options);die;
	
	if( $kyma_theme_options['color_scheme_child'] == '' ){
		wp_enqueue_style('kyma-color-scheme', get_stylesheet_directory_uri() . '/css/colors/default.css');
	} else {
		wp_enqueue_style('kyma-color-scheme', get_stylesheet_directory_uri() . '/css/colors/' . esc_attr($kyma_theme_options['color_scheme_child']) . '.css');
	}
}
add_action( 'wp_enqueue_scripts', 'frontech_enqueue_styles', 20 );

// Add child theme settings to options array - UPDATED
function frontech_updateoption_child_settings() {

	// Set possible options names
	$kyma_theme_options  = 'kyma_theme_options';
	
	// Get options values (theme options)
	$options_free = get_option( $kyma_theme_options );

	// Get child settinsg values
	$options_child_settings = get_option( 'child_theme_option_updated' );

	// Only set child settings values if not already set 
	if ( $options_child_settings != 1 ) {
		$options_free['header_topbar_bg_color'] = '#dd3333';
		$options_free['callout_bg_color'] = '#dd3333';
		$options_free['slider_title_bg_color'] = 'rgba(0,0,0,.65)';
		$options_free['slider_subtitle_bg_color'] = 'rgba(0,0,0,.4)';
		$options_free['nav_color'] = '#dd3333';
		$options_free['back_to_top'] = '#dd3333';
		$options_free['footer_bg_color'] = '#2f2f2f';
		$options_free['color_scheme_child'] = '';
		
		// Add child settings to theme options array
		update_option( $kyma_theme_options, $options_free );
	}

	// Set the child settings flag
	update_option( 'child_theme_option_updated', 1 );

}
add_action( 'init', 'frontech_updateoption_child_settings', 999 );

function frontech_excerpt_more($more)
{	
	return '<br> <br><a href="' . esc_url(get_permalink()) . '" class="btn frontech-btn"><span></span>' . esc_html__('Read More', 'frontech') . '</a>';
}

add_filter('excerpt_more', 'frontech_excerpt_more', 15);

function frontech_theme_setup()
{

	$frontech_theme_options = frontech_theme_options();
	load_child_theme_textdomain('frontech', get_template_directory() . '/lang');
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'color_scheme_child',
		'label'             => esc_html__('Color scheme', 'frontech'),
		'description'       => esc_html__('Select a color scheme', 'frontech'),
		'section'           => 'kyma_general_section',
		'type'              => 'preset',
		'priority'          => 9,
		'default'           => $frontech_theme_options['color_scheme_child'],
		'sanitize_callback' => 'esc_attr',
		'choices'    =>array(
			''=>array(
				'label' => esc_html__('Default','frontech'),
				'settings' => array(
					'kyma_theme_options[header_topbar_bg_color]' => '#dd3333',
					'kyma_theme_options[nav_color]' => '#dd3333',
					'kyma_theme_options[slider_title_bg_color]' => '#dd3333',
					'kyma_theme_options[callout_bg_color]' => '#dd3333',
					'kyma_theme_options[back_to_top]' => '#dd3333',
			   ),
			),
			'orange'=>array(
				'label' => esc_html__('Orange','frontech'),
				'settings' => array(
					'kyma_theme_options[header_topbar_bg_color]' => '#F86923',
					'kyma_theme_options[nav_color]' => '#F86923',
					'kyma_theme_options[slider_title_bg_color]' => '#F86923',
					'kyma_theme_options[callout_bg_color]' => '#F86923',
					'kyma_theme_options[back_to_top]' => '#F86923',
			   ),
			),
			'cyan'=>array(
				'label' => esc_html__('Cyan','frontech'),
				'settings' => array(
					'kyma_theme_options[header_topbar_bg_color]' => '#1ccdca',
					'kyma_theme_options[nav_color]' => '#1ccdca',
					'kyma_theme_options[slider_title_bg_color]' => '#1ccdca',
					'kyma_theme_options[callout_bg_color]' => '#1ccdca',
					'kyma_theme_options[back_to_top]' => '#1ccdca',
			   ),
			),
		)

	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'slider_title_bg_color',
		'label'             => esc_html__('Slider Title Background Color', 'frontech'),
		'section'           => 'slider_sec',
		'type'              => 'color',
		'priority'          => 10,
		'default'           => 'rgba(0,0,0,.65)',
		'choices'           => array(
			'alpha' => true
		),
		'output'            => array(
			array(
				'element'  => '.title_big:before',
				'function' => 'style',
				'property' => 'background',
			),

		),
		'transport'         => 'auto',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'slider_subtitle_bg_color',
		'label'             => esc_html__('Slider Subtitle Background Color', 'frontech'),
		'section'           => 'slider_sec',
		'type'              => 'color',
		'priority'          => 10,
		'default'           => 'rgba(0,0,0,.4)',
		'choices'           => array(
			'alpha' => true
		),
		'output'            => array(
			array(
				'element'  => '.small_subtitle:before',
				'function' => 'style',
				'property' => 'background-color',
			),

		),
		'transport'         => 'auto',

	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'footer_bg_color',
		'label'             => esc_html__('Footer Background Color', 'frontech'),
		'section'           => 'footer_sec',
		'type'              => 'color',
		'default'           => $frontech_theme_options['footer_bg_color'],
		'priority'          => 10,
		'output'            => array(
			array(
				'element'  => '#footer',
				'property' => 'background-color',
			),
		),
		'transport'         => 'postMessage',
		'js_vars'           => array(
			array(
				'element'  => '#footer',
				'function' => 'css',
				'property' => 'background-color',
			),
		),
		'sanitize_callback' => 'kyma_sanitize_color',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'header_bg_color',
		'label'             => esc_html__('Header Background Color', 'frontech'),
		'section'           => 'header_image',
		'type'              => 'color',
		'default'           => $frontech_theme_options['header_bg_color'],
		'priority'          => 10,
		'output'            => array(
			array(
				'element'  	=> '.light_header #navigation_bar, #navigation_bar',
				'property' 	=> 'background-color',
			),
			array(
				'element'	=>'#main_nav.has_mobile_menu #nav_menu:before',
				'property' 	=> 'background-color',
				'suffix'   	=> '!important'
			)
		),
		'transport'         => 'auto',
		'js_vars'           => array(
			array(
				'element'  => '.light_header #navigation_bar, #navigation_bar',
				'function' => 'css',
				'property' => 'background-color',
			),
			array(
				'element'	=>'#main_nav.has_mobile_menu #nav_menu:before',
				'property' 	=> 'background-color',
				'suffix'   	=> '!important'
			)
		),
		'sanitize_callback' => 'kyma_sanitize_color',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'contact_info_popup_enable',
		'label'             => esc_html__('Logo Popup Enable', 'frontech'),
		'description'       => esc_html__('Show/Hide logo popup', 'frontech'),
		'section'           => 'title_tagline',
		'type'              => 'switch',
		'priority'          => 40,
		'default'           => $frontech_theme_options['contact_info_popup_enable'],
		'sanitize_callback' => 'kyma_sanitize_checkbox',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'company_short_desc',
		'label'             => esc_html__('Company Description', 'frontech'),
		'section'           => 'title_tagline',
		'type'              => 'text',
		'priority'          => 40,
		'default'           => $frontech_theme_options['company_short_desc'],
		'sanitize_callback' => 'kyma_sanitize_text',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'company_address',
		'label'             => esc_html__('Company Address', 'frontech'),
		'section'           => 'title_tagline',
		'type'              => 'text',
		'priority'          => 40,
		'default'           => $frontech_theme_options['company_address'],
		'sanitize_callback' => 'kyma_sanitize_text',
	));
	
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'company_map_url',
		'label'             => esc_html__('Company Map URL', 'frontech'),
		'section'           => 'title_tagline',
		'type'              => 'text',
		'priority'          => 40,
		'default'           => $frontech_theme_options['company_map_url'],
		'sanitize_callback' => 'esc_url',
	));
	
	/* Social Link */
	Kirki::add_field('kyma_theme', array(
		'settings'          => 'social_pinterest_link',
		'label'             => esc_html__('Pinterest Profile URL', 'frontech'),
		'section'           => 'kyma_topbar_section',
		'type'              => 'url',
		'priority'          => 11,
		'default'           => $frontech_theme_options['social_pinterest_link'],
		'sanitize_callback' => 'esc_url',
	));
}
add_action('after_setup_theme', 'frontech_theme_setup');

function frontech_customize_register( $wp_customize ) {
	
	$wp_customize->remove_control('kyma_theme_options[color_scheme]');
	$wp_customize->get_setting( 'header_textcolor' )->default = '#fff';

}
add_action('customize_register', 'frontech_customize_register', 100 );

add_filter('next_post_link', 'frontech_post_link_attributes');
add_filter('previous_post_link', 'frontech_post_link_attributes');
function frontech_post_link_attributes($output) {
    $injection = 'class="btn frontech-btn"';
    return str_replace('<a href=', '<a '.$injection.' href=', $output);
}

/* Custom Sanitization Function  */
function frontech_sanitize_text($input) {
    return wp_kses_post(force_balance_tags($input));
}